# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_rc_global_optspecs
    string join \n format= json no-color no-progress q/quiet debug H/header= h/help V/version
end

function __fish_rc_needs_command
    # Figure out if the current invocation already has a command.
    set -l cmd (commandline -opc)
    set -e cmd[1]
    argparse -s (__fish_rc_global_optspecs) -- $cmd 2>/dev/null
    or return
    if set -q argv[1]
        # Also print the command, so this can be used to figure out what it is.
        echo $argv[1]
        return 1
    end
    return 0
end

function __fish_rc_using_subcommand
    set -l cmd (__fish_rc_needs_command)
    test -z "$cmd"
    and return 1
    contains -- $cmd[1] $argv
end

complete -c rc -n "__fish_rc_needs_command" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_needs_command" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_needs_command" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_needs_command" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_needs_command" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_needs_command" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_needs_command" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_needs_command" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_needs_command" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_needs_command" -f -a "alias" -d 'Manage storage service aliases'
complete -c rc -n "__fish_rc_needs_command" -f -a "admin" -d 'Manage IAM users, policies, groups, and service accounts'
complete -c rc -n "__fish_rc_needs_command" -f -a "bucket" -d 'Manage bucket-oriented workflows'
complete -c rc -n "__fish_rc_needs_command" -f -a "object" -d 'Manage object-oriented workflows'
complete -c rc -n "__fish_rc_needs_command" -f -a "ls" -d 'Deprecated: use `rc bucket list` or `rc object list`'
complete -c rc -n "__fish_rc_needs_command" -f -a "mb" -d 'Deprecated: use `rc bucket create`'
complete -c rc -n "__fish_rc_needs_command" -f -a "rb" -d 'Deprecated: use `rc bucket remove`'
complete -c rc -n "__fish_rc_needs_command" -f -a "cat" -d 'Deprecated: use `rc object show`'
complete -c rc -n "__fish_rc_needs_command" -f -a "head" -d 'Deprecated: use `rc object head`'
complete -c rc -n "__fish_rc_needs_command" -f -a "stat" -d 'Deprecated: use `rc object stat`'
complete -c rc -n "__fish_rc_needs_command" -f -a "cp" -d 'Deprecated: use `rc object copy`'
complete -c rc -n "__fish_rc_needs_command" -f -a "mv" -d 'Deprecated: use `rc object move`'
complete -c rc -n "__fish_rc_needs_command" -f -a "rm" -d 'Deprecated: use `rc object remove`'
complete -c rc -n "__fish_rc_needs_command" -f -a "pipe" -d 'Stream stdin to an object'
complete -c rc -n "__fish_rc_needs_command" -f -a "find" -d 'Deprecated: use `rc object find`'
complete -c rc -n "__fish_rc_needs_command" -f -a "event" -d 'Deprecated: use `rc bucket event`'
complete -c rc -n "__fish_rc_needs_command" -f -a "cors" -d 'Deprecated: use `rc bucket cors`'
complete -c rc -n "__fish_rc_needs_command" -f -a "diff" -d 'Show differences between locations'
complete -c rc -n "__fish_rc_needs_command" -f -a "mirror" -d 'Mirror objects between locations'
complete -c rc -n "__fish_rc_needs_command" -f -a "tree" -d 'Deprecated: use `rc object tree`'
complete -c rc -n "__fish_rc_needs_command" -f -a "share" -d 'Deprecated: use `rc object share`'
complete -c rc -n "__fish_rc_needs_command" -f -a "sql" -d 'Run S3 Select SQL on an object'
complete -c rc -n "__fish_rc_needs_command" -f -a "version" -d 'Deprecated: use `rc bucket version`'
complete -c rc -n "__fish_rc_needs_command" -f -a "tag" -d 'Manage bucket and object tags'
complete -c rc -n "__fish_rc_needs_command" -f -a "anonymous" -d 'Deprecated: use `rc bucket anonymous`'
complete -c rc -n "__fish_rc_needs_command" -f -a "quota" -d 'Deprecated: use `rc bucket quota`'
complete -c rc -n "__fish_rc_needs_command" -f -a "ilm" -d 'Deprecated: use `rc bucket lifecycle`'
complete -c rc -n "__fish_rc_needs_command" -f -a "replicate" -d 'Deprecated: use `rc bucket replication`'
complete -c rc -n "__fish_rc_needs_command" -f -a "completions" -d 'Generate shell completion scripts'
complete -c rc -n "__fish_rc_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -f -a "set" -d 'Add or update an alias'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -f -a "list" -d 'List all configured aliases'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -f -a "remove" -d 'Remove an alias'
complete -c rc -n "__fish_rc_using_subcommand alias; and not __fish_seen_subcommand_from set list remove help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l client-cert -d 'Path to PEM client certificate for mTLS' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l client-key -d 'Path to PEM client private key for mTLS' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l region -d 'AWS region (default: us-east-1)' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l signature -d 'Signature version (only v4 is currently supported)' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l bucket-lookup -d 'Bucket lookup style: auto, path, or dns (default: auto)' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l anonymous -d 'Send requests without SigV4 credentials'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l insecure -d 'Allow insecure TLS connections'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -s l -l long -d 'Show full details including endpoints'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from help" -f -a "set" -d 'Add or update an alias'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all configured aliases'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove an alias'
complete -c rc -n "__fish_rc_using_subcommand alias; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "info" -d 'Display cluster information (servers, disks, usage)'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "heal" -d 'Manage cluster healing operations'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "pool" -d 'Manage server pools and expansion status'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "expand" -d 'Manage post-expansion data rebalancing'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "decommission" -d 'Manage server pool decommissioning'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "rebalance" -d 'Manage post-expansion rebalancing'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "user" -d 'Manage IAM users'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "policy" -d 'Manage IAM policies'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "group" -d 'Manage IAM groups'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "service-account" -d 'Manage service accounts'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "access-key" -d 'Inspect access key identities'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "service" -d 'Control the server process (restart, stop, freeze, unfreeze)'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "replicate" -d 'Manage site replication across clusters'
complete -c rc -n "__fish_rc_using_subcommand admin; and not __fish_seen_subcommand_from info heal pool expand decommission rebalance user policy group service-account access-key service replicate help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -f -a "cluster" -d 'Display cluster overview information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -f -a "server" -d 'Display server information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -f -a "disk" -d 'Display disk information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from info" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -f -a "status" -d 'Display current heal status'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -f -a "start" -d 'Start a heal operation'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -f -a "stop" -d 'Stop a running heal operation'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from heal" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -f -a "list" -d 'List server pools'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -f -a "status" -d 'Show server pool status'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from pool" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -f -a "start" -d 'Start post-expansion data rebalancing'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -f -a "status" -d 'Show post-expansion rebalance status'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -f -a "stop" -d 'Stop a running post-expansion rebalance'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from expand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -f -a "start" -d 'Start decommissioning a pool'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -f -a "status" -d 'Show decommissioning status'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -f -a "cancel" -d 'Cancel decommissioning a pool'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -f -a "clear" -d 'Clear failed or canceled decommissioning metadata for a pool'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from decommission" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -f -a "start" -d 'Start a rebalance operation'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -f -a "status" -d 'Show rebalance status'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -f -a "stop" -d 'Stop a running rebalance operation'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from rebalance" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -f -a "ls" -d 'List all users'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -f -a "add" -d 'Add a new user'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -f -a "info" -d 'Get user information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -f -a "rm" -d 'Remove a user'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -f -a "enable" -d 'Enable a user'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -f -a "disable" -d 'Disable a user'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from user" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -f -a "ls" -d 'List all policies'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -f -a "create" -d 'Create a new policy'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -f -a "info" -d 'Get policy information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -f -a "rm" -d 'Remove a policy'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -f -a "attach" -d 'Attach policy to a user or group'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from policy" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "ls" -d 'List all groups'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "add" -d 'Create a new group'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "info" -d 'Get group information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "rm" -d 'Remove a group'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "enable" -d 'Enable a group'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "disable" -d 'Disable a group'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "add-members" -d 'Add members to a group'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "rm-members" -d 'Remove members from a group'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from group" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -f -a "ls" -d 'List service accounts'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -f -a "create" -d 'Create a new service account'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -f -a "info" -d 'Get service account information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -f -a "rm" -d 'Remove a service account'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service-account" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -f -a "info" -d 'Get access key information'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from access-key" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -f -a "restart" -d 'Restart the server (graceful shutdown; process manager relaunches)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -f -a "stop" -d 'Stop the server gracefully'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -f -a "freeze" -d 'Set the service freeze flag (advisory)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -f -a "unfreeze" -d 'Clear the service freeze flag'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from service" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -f -a "add" -d 'Add sites (given as alias names) to a site replication cluster'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -f -a "info" -d 'Show site replication configuration'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -f -a "status" -d 'Show site replication status'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -f -a "remove" -d 'Remove sites from the site replication cluster'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from replicate" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "info" -d 'Display cluster information (servers, disks, usage)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "heal" -d 'Manage cluster healing operations'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "pool" -d 'Manage server pools and expansion status'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "expand" -d 'Manage post-expansion data rebalancing'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "decommission" -d 'Manage server pool decommissioning'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "rebalance" -d 'Manage post-expansion rebalancing'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "user" -d 'Manage IAM users'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "policy" -d 'Manage IAM policies'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "group" -d 'Manage IAM groups'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "service-account" -d 'Manage service accounts'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "access-key" -d 'Inspect access key identities'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "service" -d 'Control the server process (restart, stop, freeze, unfreeze)'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "replicate" -d 'Manage site replication across clusters'
complete -c rc -n "__fish_rc_using_subcommand admin; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "list" -d 'List buckets for an alias, or objects within a bucket path'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "create" -d 'Create a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "remove" -d 'Remove a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "event" -d 'Manage bucket notification rules'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "cors" -d 'Manage bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "encryption" -d 'Manage bucket default encryption'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "version" -d 'Manage bucket versioning'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "quota" -d 'Manage bucket quota'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "anonymous" -d 'Manage anonymous bucket access'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "lifecycle" -d 'Manage bucket lifecycle rules, tiers, and restores'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "replication" -d 'Manage bucket replication rules and status'
complete -c rc -n "__fish_rc_using_subcommand bucket; and not __fish_seen_subcommand_from list create remove event cors encryption version quota anonymous lifecycle replication help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -s r -l recursive -d 'List recursively'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l versions -d 'Show versions (requires versioning support)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l incomplete -d 'Include incomplete uploads'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l summarize -d 'Summarize output (show totals only)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l region -d 'Region for the bucket (overrides alias default)' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -s p -l ignore-existing -d 'Ignore error if bucket already exists'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l with-lock -d 'Enable object locking on the bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l with-versioning -d 'Enable versioning on the bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from create" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -l force -d 'Force remove even if bucket is not empty (deletes all objects first)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -l dangerous -d 'Remove bucket even if it has incomplete multipart uploads'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -f -a "add" -d 'Add or replace a bucket notification rule for an ARN'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -f -a "list" -d 'List bucket notification rules'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -f -a "remove" -d 'Remove bucket notification rules by target ARN'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from event" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -f -a "list" -d 'List bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -f -a "set" -d 'Replace bucket CORS rules from a JSON or XML file'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -f -a "remove" -d 'Remove bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from cors" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -f -a "set" -d 'Set bucket default encryption'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -f -a "info" -d 'Show bucket default encryption'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -f -a "clear" -d 'Clear bucket default encryption'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from encryption" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -f -a "enable" -d 'Enable versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -f -a "suspend" -d 'Suspend versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -f -a "info" -d 'Get versioning status for a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -f -a "list" -d 'List object versions'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from version" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -f -a "set" -d 'Set bucket quota'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -f -a "info" -d 'Show bucket quota information'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -f -a "clear" -d 'Clear bucket quota'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from quota" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -f -a "set" -d 'Set anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -f -a "set-json" -d 'Set anonymous access from a policy JSON file'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -f -a "get" -d 'Get anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -f -a "get-json" -d 'Get anonymous policy JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -f -a "list" -d 'List anonymous policies'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -f -a "links" -d 'List public links for anonymous readable prefixes'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from anonymous" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -f -a "rule" -d 'Manage lifecycle rules on a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -f -a "tier" -d 'Manage remote storage tiers'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -f -a "restore" -d 'Restore a transitioned (archived) object'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from lifecycle" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "add" -d 'Add a new replication rule'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "update" -d 'Update an existing replication rule'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "list" -d 'List replication rules for a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "status" -d 'Show replication status/metrics for a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "remove" -d 'Remove replication rules from a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "export" -d 'Export replication configuration as JSON'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "import" -d 'Import replication configuration from a JSON file'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from replication" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "list" -d 'List buckets for an alias, or objects within a bucket path'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "create" -d 'Create a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove a bucket'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "event" -d 'Manage bucket notification rules'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "cors" -d 'Manage bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "encryption" -d 'Manage bucket default encryption'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "version" -d 'Manage bucket versioning'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "quota" -d 'Manage bucket quota'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "anonymous" -d 'Manage anonymous bucket access'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "lifecycle" -d 'Manage bucket lifecycle rules, tiers, and restores'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "replication" -d 'Manage bucket replication rules and status'
complete -c rc -n "__fish_rc_using_subcommand bucket; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "list" -d 'List objects within a bucket path'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "copy" -d 'Copy objects between local and remote locations'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "move" -d 'Move objects between local and remote locations'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "remove" -d 'Remove objects'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "stat" -d 'Show object metadata'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "show" -d 'Print the full object body'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "head" -d 'Print the first lines or bytes of an object'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "find" -d 'Search for objects by filters'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "tree" -d 'Display objects in a tree view'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "share" -d 'Generate a presigned object URL'
complete -c rc -n "__fish_rc_using_subcommand object; and not __fish_seen_subcommand_from list copy move remove stat show head find tree share help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -s r -l recursive -d 'List recursively'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l versions -d 'Show versions (requires versioning support)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l incomplete -d 'Include incomplete uploads'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l summarize -d 'Summarize output (show totals only)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l storage-class -d 'Storage class for destination (S3 only)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l content-type -d 'Content type for uploaded files' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l enc-s3 -d 'Apply SSE-S3 to the remote destination path' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l enc-kms -d 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -s r -l recursive -d 'Copy recursively'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -s p -l preserve -d 'Preserve file attributes'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l continue-on-error -d 'Continue on errors'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l overwrite -d 'Overwrite destination if it exists'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l dry-run -d 'Only show what would be copied (dry run)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from copy" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l enc-s3 -d 'Apply SSE-S3 to the remote destination path' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l enc-kms -d 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -s r -l recursive -d 'Move recursively'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l continue-on-error -d 'Continue on errors'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l dry-run -d 'Only show what would be moved (dry run)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from move" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -s r -l recursive -d 'Remove recursively (remove all objects with the given prefix)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -s f -l force -d 'Force removal without confirmation'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l dry-run -d 'Only show what would be deleted (dry run)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l incomplete -d 'Remove incomplete multipart uploads older than specified duration'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l versions -d 'Include versions (requires versioning support)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l bypass -d 'Bypass governance retention'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l purge -d 'Permanently delete objects using the RustFS force-delete header'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -l version-id -d 'Show version ID information' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -l rewind -d 'Rewind to a specific time' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from stat" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l enc-key -d 'Encrypt/decrypt with the given key (base64 encoded)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l rewind -d 'Rewind to a specific time' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l version-id -d 'Specific version ID to retrieve' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from show" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -s n -l lines -d 'Number of lines to display (default: 10)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -s c -l bytes -d 'Display first N bytes instead of lines' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -l version-id -d 'Specific version ID to retrieve' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from head" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l name -d 'Pattern to match object names (glob-style: *, ?)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l larger -d 'Match objects larger than size (e.g., 1K, 1M, 1G)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l smaller -d 'Match objects smaller than size (e.g., 1K, 1M, 1G)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l newer -d 'Match objects newer than duration (e.g., 1h, 1d, 7d)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l older -d 'Match objects older than duration (e.g., 1h, 1d, 7d)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l maxdepth -d 'Maximum depth to search (0 = unlimited)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l exec -d 'Execute command for each match (use {} as placeholder)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l count -d 'Print only count of matches'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l print -d 'Print full path (default: relative to search path)'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from find" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s L -l level -d 'Maximum depth to display' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s P -l pattern -d 'Pattern to include (glob-style)' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s s -l size -d 'Show file sizes'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s d -l dirs-only -d 'Show only directories'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s f -l full-path -d 'Show full path prefix'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from tree" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -s e -l expire -d 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -l content-type -d 'Content-Type for upload URL' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -l upload -d 'Generate upload URL instead of download URL'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from share" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "list" -d 'List objects within a bucket path'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "copy" -d 'Copy objects between local and remote locations'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "move" -d 'Move objects between local and remote locations'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove objects'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "stat" -d 'Show object metadata'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "show" -d 'Print the full object body'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "head" -d 'Print the first lines or bytes of an object'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "find" -d 'Search for objects by filters'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "tree" -d 'Display objects in a tree view'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "share" -d 'Generate a presigned object URL'
complete -c rc -n "__fish_rc_using_subcommand object; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand ls" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand ls" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand ls" -s r -l recursive -d 'List recursively'
complete -c rc -n "__fish_rc_using_subcommand ls" -l versions -d 'Show versions (requires versioning support)'
complete -c rc -n "__fish_rc_using_subcommand ls" -l incomplete -d 'Include incomplete uploads'
complete -c rc -n "__fish_rc_using_subcommand ls" -l summarize -d 'Summarize output (show totals only)'
complete -c rc -n "__fish_rc_using_subcommand ls" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand ls" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand ls" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand ls" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand ls" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand ls" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand ls" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand mb" -l region -d 'Region for the bucket (overrides alias default)' -r
complete -c rc -n "__fish_rc_using_subcommand mb" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand mb" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand mb" -s p -l ignore-existing -d 'Ignore error if bucket already exists'
complete -c rc -n "__fish_rc_using_subcommand mb" -l with-lock -d 'Enable object locking on the bucket'
complete -c rc -n "__fish_rc_using_subcommand mb" -l with-versioning -d 'Enable versioning on the bucket'
complete -c rc -n "__fish_rc_using_subcommand mb" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand mb" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand mb" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand mb" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand mb" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand mb" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand mb" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand rb" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand rb" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand rb" -l force -d 'Force remove even if bucket is not empty (deletes all objects first)'
complete -c rc -n "__fish_rc_using_subcommand rb" -l dangerous -d 'Remove bucket even if it has incomplete multipart uploads'
complete -c rc -n "__fish_rc_using_subcommand rb" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand rb" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand rb" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand rb" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand rb" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand rb" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand rb" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand cat" -l enc-key -d 'Encrypt/decrypt with the given key (base64 encoded)' -r
complete -c rc -n "__fish_rc_using_subcommand cat" -l rewind -d 'Rewind to a specific time' -r
complete -c rc -n "__fish_rc_using_subcommand cat" -l version-id -d 'Specific version ID to retrieve' -r
complete -c rc -n "__fish_rc_using_subcommand cat" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand cat" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand cat" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand cat" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand cat" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand cat" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand cat" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand cat" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand cat" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand head" -s n -l lines -d 'Number of lines to display (default: 10)' -r
complete -c rc -n "__fish_rc_using_subcommand head" -s c -l bytes -d 'Display first N bytes instead of lines' -r
complete -c rc -n "__fish_rc_using_subcommand head" -l version-id -d 'Specific version ID to retrieve' -r
complete -c rc -n "__fish_rc_using_subcommand head" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand head" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand head" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand head" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand head" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand head" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand head" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand head" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand head" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand stat" -l version-id -d 'Show version ID information' -r
complete -c rc -n "__fish_rc_using_subcommand stat" -l rewind -d 'Rewind to a specific time' -r
complete -c rc -n "__fish_rc_using_subcommand stat" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand stat" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand stat" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand stat" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand stat" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand stat" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand stat" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand stat" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand stat" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand cp" -l storage-class -d 'Storage class for destination (S3 only)' -r
complete -c rc -n "__fish_rc_using_subcommand cp" -l content-type -d 'Content type for uploaded files' -r
complete -c rc -n "__fish_rc_using_subcommand cp" -l enc-s3 -d 'Apply SSE-S3 to the remote destination path' -r
complete -c rc -n "__fish_rc_using_subcommand cp" -l enc-kms -d 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID' -r
complete -c rc -n "__fish_rc_using_subcommand cp" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand cp" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand cp" -s r -l recursive -d 'Copy recursively'
complete -c rc -n "__fish_rc_using_subcommand cp" -s p -l preserve -d 'Preserve file attributes'
complete -c rc -n "__fish_rc_using_subcommand cp" -l continue-on-error -d 'Continue on errors'
complete -c rc -n "__fish_rc_using_subcommand cp" -l overwrite -d 'Overwrite destination if it exists'
complete -c rc -n "__fish_rc_using_subcommand cp" -l dry-run -d 'Only show what would be copied (dry run)'
complete -c rc -n "__fish_rc_using_subcommand cp" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand cp" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand cp" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand cp" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand cp" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand cp" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand cp" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand mv" -l enc-s3 -d 'Apply SSE-S3 to the remote destination path' -r
complete -c rc -n "__fish_rc_using_subcommand mv" -l enc-kms -d 'Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID' -r
complete -c rc -n "__fish_rc_using_subcommand mv" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand mv" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand mv" -s r -l recursive -d 'Move recursively'
complete -c rc -n "__fish_rc_using_subcommand mv" -l continue-on-error -d 'Continue on errors'
complete -c rc -n "__fish_rc_using_subcommand mv" -l dry-run -d 'Only show what would be moved (dry run)'
complete -c rc -n "__fish_rc_using_subcommand mv" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand mv" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand mv" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand mv" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand mv" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand mv" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand mv" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand rm" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand rm" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand rm" -s r -l recursive -d 'Remove recursively (remove all objects with the given prefix)'
complete -c rc -n "__fish_rc_using_subcommand rm" -s f -l force -d 'Force removal without confirmation'
complete -c rc -n "__fish_rc_using_subcommand rm" -l dry-run -d 'Only show what would be deleted (dry run)'
complete -c rc -n "__fish_rc_using_subcommand rm" -l incomplete -d 'Remove incomplete multipart uploads older than specified duration'
complete -c rc -n "__fish_rc_using_subcommand rm" -l versions -d 'Include versions (requires versioning support)'
complete -c rc -n "__fish_rc_using_subcommand rm" -l bypass -d 'Bypass governance retention'
complete -c rc -n "__fish_rc_using_subcommand rm" -l purge -d 'Permanently delete objects using the RustFS force-delete header'
complete -c rc -n "__fish_rc_using_subcommand rm" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand rm" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand rm" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand rm" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand rm" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand rm" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand rm" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand pipe" -l content-type -d 'Content type for the uploaded object' -r
complete -c rc -n "__fish_rc_using_subcommand pipe" -l storage-class -d 'Storage class for the object' -r
complete -c rc -n "__fish_rc_using_subcommand pipe" -l enc-kms -d 'Apply SSE-KMS to the upload target' -r
complete -c rc -n "__fish_rc_using_subcommand pipe" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand pipe" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand pipe" -l enc-s3 -d 'Apply SSE-S3 to the upload target'
complete -c rc -n "__fish_rc_using_subcommand pipe" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand pipe" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand pipe" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand pipe" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand pipe" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand pipe" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand pipe" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand find" -l name -d 'Pattern to match object names (glob-style: *, ?)' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l larger -d 'Match objects larger than size (e.g., 1K, 1M, 1G)' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l smaller -d 'Match objects smaller than size (e.g., 1K, 1M, 1G)' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l newer -d 'Match objects newer than duration (e.g., 1h, 1d, 7d)' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l older -d 'Match objects older than duration (e.g., 1h, 1d, 7d)' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l maxdepth -d 'Maximum depth to search (0 = unlimited)' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l exec -d 'Execute command for each match (use {} as placeholder)' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand find" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand find" -l count -d 'Print only count of matches'
complete -c rc -n "__fish_rc_using_subcommand find" -l print -d 'Print full path (default: relative to search path)'
complete -c rc -n "__fish_rc_using_subcommand find" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand find" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand find" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand find" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand find" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand find" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand find" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -f -a "add" -d 'Add or replace a bucket notification rule for an ARN'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -f -a "list" -d 'List bucket notification rules'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -f -a "remove" -d 'Remove bucket notification rules by target ARN'
complete -c rc -n "__fish_rc_using_subcommand event; and not __fish_seen_subcommand_from add list remove help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -l event -d 'Event pattern (repeatable; comma-separated values are also accepted)' -r
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from add" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from help" -f -a "add" -d 'Add or replace a bucket notification rule for an ARN'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from help" -f -a "list" -d 'List bucket notification rules'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove bucket notification rules by target ARN'
complete -c rc -n "__fish_rc_using_subcommand event; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -f -a "list" -d 'List bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -f -a "set" -d 'Replace bucket CORS rules from a JSON or XML file'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -f -a "remove" -d 'Remove bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand cors; and not __fish_seen_subcommand_from list set remove help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -l file -d 'Path to the CORS configuration file, or \'-\' to read from stdin' -r
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from help" -f -a "list" -d 'List bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from help" -f -a "set" -d 'Replace bucket CORS rules from a JSON or XML file'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand cors; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand diff" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand diff" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand diff" -s r -l recursive -d 'Recursive comparison'
complete -c rc -n "__fish_rc_using_subcommand diff" -l diff-only -d 'Show only differences (default: show all)'
complete -c rc -n "__fish_rc_using_subcommand diff" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand diff" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand diff" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand diff" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand diff" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand diff" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand diff" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand mirror" -s P -l parallel -d 'Number of parallel operations' -r
complete -c rc -n "__fish_rc_using_subcommand mirror" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand mirror" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand mirror" -l remove -d 'Remove extra objects at destination'
complete -c rc -n "__fish_rc_using_subcommand mirror" -l overwrite -d 'Overwrite existing objects'
complete -c rc -n "__fish_rc_using_subcommand mirror" -s n -l dry-run -d 'Dry run (show what would be done without doing it)'
complete -c rc -n "__fish_rc_using_subcommand mirror" -l quiet -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand mirror" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand mirror" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand mirror" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand mirror" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand mirror" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand mirror" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand tree" -s L -l level -d 'Maximum depth to display' -r
complete -c rc -n "__fish_rc_using_subcommand tree" -s P -l pattern -d 'Pattern to include (glob-style)' -r
complete -c rc -n "__fish_rc_using_subcommand tree" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand tree" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand tree" -s s -l size -d 'Show file sizes'
complete -c rc -n "__fish_rc_using_subcommand tree" -s d -l dirs-only -d 'Show only directories'
complete -c rc -n "__fish_rc_using_subcommand tree" -s f -l full-path -d 'Show full path prefix'
complete -c rc -n "__fish_rc_using_subcommand tree" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand tree" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand tree" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand tree" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand tree" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand tree" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand tree" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand share" -s e -l expire -d 'Expiration time (e.g., 1h, 1d, 7d). Default: 7d' -r
complete -c rc -n "__fish_rc_using_subcommand share" -l content-type -d 'Content-Type for upload URL' -r
complete -c rc -n "__fish_rc_using_subcommand share" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand share" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand share" -l upload -d 'Generate upload URL instead of download URL'
complete -c rc -n "__fish_rc_using_subcommand share" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand share" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand share" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand share" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand share" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand share" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand share" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand sql" -l query -d 'SQL expression (S3 Select)' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l input-format -d 'Input object format' -r -f -a "csv\t''
json\t'Newline-delimited JSON (S3 Select `Type=LINES`)'
parquet\t''"
complete -c rc -n "__fish_rc_using_subcommand sql" -l output-format -d 'Select result format' -r -f -a "csv\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand sql" -l compression -d 'Compression of the stored object (input decompression)' -r -f -a "none\t''
gzip\t''
bzip2\t''"
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-file-header-info -d 'CSV input header handling' -r -f -a "none\t''
ignore\t''
use\t''"
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-input-field-delimiter -d 'CSV input field delimiter' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-input-quote -d 'CSV input quote character' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-input-quote-escape -d 'CSV input quote escape character' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-input-comment -d 'CSV input comment character' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-output-field-delimiter -d 'CSV output field delimiter' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-output-record-delimiter -d 'CSV output record delimiter' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-output-quote -d 'CSV output quote character' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-output-quote-escape -d 'CSV output quote escape character' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l csv-output-quote-fields -d 'CSV output quote behavior' -r -f -a "always\t''
as-needed\t''"
complete -c rc -n "__fish_rc_using_subcommand sql" -l json-type -d 'JSON input shape' -r -f -a "lines\t''
document\t''"
complete -c rc -n "__fish_rc_using_subcommand sql" -l json-output-record-delimiter -d 'JSON output record delimiter' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l scan-start -d 'Select ScanRange start byte' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l scan-end -d 'Select ScanRange end byte' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l sse-customer-algorithm -d 'SSE-C customer algorithm, usually AES256' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l sse-customer-key -d 'SSE-C customer key' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l sse-customer-key-md5 -d 'SSE-C customer key MD5' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand sql" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand sql" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand sql" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand sql" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand sql" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand sql" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand sql" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rc -n "__fish_rc_using_subcommand sql" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -f -a "enable" -d 'Enable versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -f -a "suspend" -d 'Suspend versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -f -a "info" -d 'Get versioning status for a bucket'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -f -a "list" -d 'List object versions'
complete -c rc -n "__fish_rc_using_subcommand version; and not __fish_seen_subcommand_from enable suspend info list help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from enable" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from suspend" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from info" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -s n -l max -d 'Maximum number of versions to show' -r
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from help" -f -a "enable" -d 'Enable versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from help" -f -a "suspend" -d 'Suspend versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from help" -f -a "info" -d 'Get versioning status for a bucket'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from help" -f -a "list" -d 'List object versions'
complete -c rc -n "__fish_rc_using_subcommand version; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -f -a "list" -d 'List tags for a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -f -a "set" -d 'Set tags for a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -f -a "remove" -d 'Remove all tags from a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand tag; and not __fish_seen_subcommand_from list set remove help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -s t -l tags -d 'Tags to set (key=value format, can specify multiple)' -r
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from help" -f -a "list" -d 'List tags for a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from help" -f -a "set" -d 'Set tags for a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove all tags from a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand tag; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -f -a "set" -d 'Set anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -f -a "set-json" -d 'Set anonymous access from a policy JSON file'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -f -a "get" -d 'Get anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -f -a "get-json" -d 'Get anonymous policy JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -f -a "list" -d 'List anonymous policies'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -f -a "links" -d 'List public links for anonymous readable prefixes'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and not __fish_seen_subcommand_from set set-json get get-json list links help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from set-json" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from get-json" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -s r -l recursive -d 'Recursively list links'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from links" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from help" -f -a "set" -d 'Set anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from help" -f -a "set-json" -d 'Set anonymous access from a policy JSON file'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from help" -f -a "get" -d 'Get anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from help" -f -a "get-json" -d 'Get anonymous policy JSON'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from help" -f -a "list" -d 'List anonymous policies'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from help" -f -a "links" -d 'List public links for anonymous readable prefixes'
complete -c rc -n "__fish_rc_using_subcommand anonymous; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -f -a "set" -d 'Set bucket quota'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -f -a "info" -d 'Show bucket quota information'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -f -a "clear" -d 'Clear bucket quota'
complete -c rc -n "__fish_rc_using_subcommand quota; and not __fish_seen_subcommand_from set info clear help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from set" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from info" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from clear" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from help" -f -a "set" -d 'Set bucket quota'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from help" -f -a "info" -d 'Show bucket quota information'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from help" -f -a "clear" -d 'Clear bucket quota'
complete -c rc -n "__fish_rc_using_subcommand quota; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -f -a "rule" -d 'Manage lifecycle rules on a bucket'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -f -a "tier" -d 'Manage remote storage tiers'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -f -a "restore" -d 'Restore a transitioned (archived) object'
complete -c rc -n "__fish_rc_using_subcommand ilm; and not __fish_seen_subcommand_from rule tier restore help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -f -a "add" -d 'Add a new lifecycle rule to a bucket'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -f -a "edit" -d 'Edit an existing lifecycle rule'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -f -a "list" -d 'List lifecycle rules on a bucket'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -f -a "remove" -d 'Remove lifecycle rules from a bucket'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -f -a "export" -d 'Export lifecycle rules as JSON'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -f -a "import" -d 'Import lifecycle rules from a JSON file'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from rule" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -f -a "add" -d 'Add a new remote storage tier'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -f -a "edit" -d 'Edit tier credentials'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -f -a "list" -d 'List configured storage tiers'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -f -a "info" -d 'Show tier statistics'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -f -a "remove" -d 'Remove a storage tier'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from tier" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -l days -d 'Number of days to keep the restored copy' -r
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from restore" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from help" -f -a "rule" -d 'Manage lifecycle rules on a bucket'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from help" -f -a "tier" -d 'Manage remote storage tiers'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from help" -f -a "restore" -d 'Restore a transitioned (archived) object'
complete -c rc -n "__fish_rc_using_subcommand ilm; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "add" -d 'Add a new replication rule'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "update" -d 'Update an existing replication rule'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "list" -d 'List replication rules for a bucket'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "status" -d 'Show replication status/metrics for a bucket'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "remove" -d 'Remove replication rules from a bucket'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "export" -d 'Export replication configuration as JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "import" -d 'Import replication configuration from a JSON file'
complete -c rc -n "__fish_rc_using_subcommand replicate; and not __fish_seen_subcommand_from add update list status remove export import help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l remote-bucket -d 'Remote target bucket (TARGET_ALIAS/BUCKET)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l replicate -d 'Replication flags (comma-separated: delete,delete-marker,existing-objects)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l priority -d 'Rule priority (higher = more important)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l storage-class -d 'Storage class override at destination' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l bandwidth -d 'Bandwidth limit in bytes/sec (0 = unlimited)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l prefix -d 'Key prefix filter' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l id -d 'Rule identifier (auto-generated if not specified)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l healthcheck-seconds -d 'Health check interval in seconds' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l ca-cert -d 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server' -r -F
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l sync -d 'Enable synchronous replication'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l disable-proxy -d 'Disable replication proxy'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l insecure -d 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from add" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l id -d 'Rule ID to update' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l replicate -d 'Replication flags (comma-separated: delete,delete-marker,existing-objects)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l priority -d 'Rule priority (higher = more important)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l storage-class -d 'Storage class override at destination' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l bandwidth -d 'Bandwidth limit in bytes/sec (0 = unlimited)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l sync -d 'Enable or disable synchronous replication' -r -f -a "true\t''
false\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l prefix -d 'Key prefix filter' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l healthcheck-seconds -d 'Health check interval in seconds' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l disable-proxy -d 'Disable replication proxy' -r -f -a "true\t''
false\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l ca-cert -d 'Read a local PEM CA certificate file and upload its content for this bucket replication target. The path is resolved on the CLI machine, not on the RustFS server' -r -F
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l status -d 'Enable or disable the rule' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l insecure -d 'Skip TLS certificate verification for this bucket replication target. Intended for development or test environments'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from update" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from status" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l id -d 'Rule ID to remove (omit for --all)' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l all -d 'Remove all replication rules'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from remove" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from export" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -l force -d 'Force operation even if capability detection fails'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from import" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "add" -d 'Add a new replication rule'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "update" -d 'Update an existing replication rule'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "list" -d 'List replication rules for a bucket'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "status" -d 'Show replication status/metrics for a bucket'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove replication rules from a bucket'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "export" -d 'Export replication configuration as JSON'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "import" -d 'Import replication configuration from a JSON file'
complete -c rc -n "__fish_rc_using_subcommand replicate; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand completions" -l format -d 'Output format: auto-detect, human-readable, or JSON' -r -f -a "auto\t''
human\t''
json\t''"
complete -c rc -n "__fish_rc_using_subcommand completions" -s H -l header -d 'Add an x-amz-* request header to signed S3 requests' -r
complete -c rc -n "__fish_rc_using_subcommand completions" -l json -d 'Output format: human-readable or JSON'
complete -c rc -n "__fish_rc_using_subcommand completions" -l no-color -d 'Disable colored output'
complete -c rc -n "__fish_rc_using_subcommand completions" -l no-progress -d 'Disable progress bar'
complete -c rc -n "__fish_rc_using_subcommand completions" -s q -l quiet -d 'Suppress non-error output'
complete -c rc -n "__fish_rc_using_subcommand completions" -l debug -d 'Enable debug logging'
complete -c rc -n "__fish_rc_using_subcommand completions" -s h -l help -d 'Print help'
complete -c rc -n "__fish_rc_using_subcommand completions" -s V -l version -d 'Print version'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "alias" -d 'Manage storage service aliases'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "admin" -d 'Manage IAM users, policies, groups, and service accounts'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "bucket" -d 'Manage bucket-oriented workflows'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "object" -d 'Manage object-oriented workflows'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "ls" -d 'Deprecated: use `rc bucket list` or `rc object list`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "mb" -d 'Deprecated: use `rc bucket create`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "rb" -d 'Deprecated: use `rc bucket remove`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "cat" -d 'Deprecated: use `rc object show`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "head" -d 'Deprecated: use `rc object head`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "stat" -d 'Deprecated: use `rc object stat`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "cp" -d 'Deprecated: use `rc object copy`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "mv" -d 'Deprecated: use `rc object move`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "rm" -d 'Deprecated: use `rc object remove`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "pipe" -d 'Stream stdin to an object'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "find" -d 'Deprecated: use `rc object find`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "event" -d 'Deprecated: use `rc bucket event`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "cors" -d 'Deprecated: use `rc bucket cors`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "diff" -d 'Show differences between locations'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "mirror" -d 'Mirror objects between locations'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "tree" -d 'Deprecated: use `rc object tree`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "share" -d 'Deprecated: use `rc object share`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "sql" -d 'Run S3 Select SQL on an object'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "version" -d 'Deprecated: use `rc bucket version`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "tag" -d 'Manage bucket and object tags'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "anonymous" -d 'Deprecated: use `rc bucket anonymous`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "quota" -d 'Deprecated: use `rc bucket quota`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "ilm" -d 'Deprecated: use `rc bucket lifecycle`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "replicate" -d 'Deprecated: use `rc bucket replication`'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "completions" -d 'Generate shell completion scripts'
complete -c rc -n "__fish_rc_using_subcommand help; and not __fish_seen_subcommand_from alias admin bucket object ls mb rb cat head stat cp mv rm pipe find event cors diff mirror tree share sql version tag anonymous quota ilm replicate completions help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from alias" -f -a "set" -d 'Add or update an alias'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from alias" -f -a "list" -d 'List all configured aliases'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from alias" -f -a "remove" -d 'Remove an alias'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "info" -d 'Display cluster information (servers, disks, usage)'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "heal" -d 'Manage cluster healing operations'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "pool" -d 'Manage server pools and expansion status'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "expand" -d 'Manage post-expansion data rebalancing'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "decommission" -d 'Manage server pool decommissioning'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "rebalance" -d 'Manage post-expansion rebalancing'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "user" -d 'Manage IAM users'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "policy" -d 'Manage IAM policies'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "group" -d 'Manage IAM groups'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "service-account" -d 'Manage service accounts'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "access-key" -d 'Inspect access key identities'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "service" -d 'Control the server process (restart, stop, freeze, unfreeze)'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from admin" -f -a "replicate" -d 'Manage site replication across clusters'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "list" -d 'List buckets for an alias, or objects within a bucket path'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "create" -d 'Create a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "remove" -d 'Remove a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "event" -d 'Manage bucket notification rules'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "cors" -d 'Manage bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "encryption" -d 'Manage bucket default encryption'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "version" -d 'Manage bucket versioning'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "quota" -d 'Manage bucket quota'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "anonymous" -d 'Manage anonymous bucket access'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "lifecycle" -d 'Manage bucket lifecycle rules, tiers, and restores'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from bucket" -f -a "replication" -d 'Manage bucket replication rules and status'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "list" -d 'List objects within a bucket path'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "copy" -d 'Copy objects between local and remote locations'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "move" -d 'Move objects between local and remote locations'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "remove" -d 'Remove objects'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "stat" -d 'Show object metadata'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "show" -d 'Print the full object body'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "head" -d 'Print the first lines or bytes of an object'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "find" -d 'Search for objects by filters'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "tree" -d 'Display objects in a tree view'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from object" -f -a "share" -d 'Generate a presigned object URL'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from event" -f -a "add" -d 'Add or replace a bucket notification rule for an ARN'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from event" -f -a "list" -d 'List bucket notification rules'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from event" -f -a "remove" -d 'Remove bucket notification rules by target ARN'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from cors" -f -a "list" -d 'List bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from cors" -f -a "set" -d 'Replace bucket CORS rules from a JSON or XML file'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from cors" -f -a "remove" -d 'Remove bucket CORS rules'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from version" -f -a "enable" -d 'Enable versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from version" -f -a "suspend" -d 'Suspend versioning for a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from version" -f -a "info" -d 'Get versioning status for a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from version" -f -a "list" -d 'List object versions'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from tag" -f -a "list" -d 'List tags for a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from tag" -f -a "set" -d 'Set tags for a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from tag" -f -a "remove" -d 'Remove all tags from a bucket or object'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from anonymous" -f -a "set" -d 'Set anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from anonymous" -f -a "set-json" -d 'Set anonymous access from a policy JSON file'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from anonymous" -f -a "get" -d 'Get anonymous access permission'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from anonymous" -f -a "get-json" -d 'Get anonymous policy JSON'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from anonymous" -f -a "list" -d 'List anonymous policies'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from anonymous" -f -a "links" -d 'List public links for anonymous readable prefixes'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from quota" -f -a "set" -d 'Set bucket quota'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from quota" -f -a "info" -d 'Show bucket quota information'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from quota" -f -a "clear" -d 'Clear bucket quota'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from ilm" -f -a "rule" -d 'Manage lifecycle rules on a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from ilm" -f -a "tier" -d 'Manage remote storage tiers'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from ilm" -f -a "restore" -d 'Restore a transitioned (archived) object'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from replicate" -f -a "add" -d 'Add a new replication rule'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from replicate" -f -a "update" -d 'Update an existing replication rule'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from replicate" -f -a "list" -d 'List replication rules for a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from replicate" -f -a "status" -d 'Show replication status/metrics for a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from replicate" -f -a "remove" -d 'Remove replication rules from a bucket'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from replicate" -f -a "export" -d 'Export replication configuration as JSON'
complete -c rc -n "__fish_rc_using_subcommand help; and __fish_seen_subcommand_from replicate" -f -a "import" -d 'Import replication configuration from a JSON file'
